=======
Credits
=======

Development Lead
----------------

* Kevin Michael Engel <kevin.m.engel@gmail.com>

Contributors
------------

* Joscha Krieglsteiner <j.krieglsteiner@tu-bs.de>
* Alexander Herwig <a.herwig@tu-bs.de>
* Onur Deniz <o.deniz@tu-bs.de>
